<?php
// ------------------------------------------------------------------------------
// Template tags definitions
// Useful to include a jmi map or link to a post map in the theme where it is not possible with the plugin
// For exemple in the loop for search results or archive list
// ------------------------------------------------------------------------------
 
/**
 * Construct the html and javacript snippets to include the jmi map
 *
 * @param array    $opt the map options
 * @return string  the html and javascript snippets to display a map
 */
function jmimap($opt) { 
    wp_enqueue_script('swfobject');
    $map_options = getDefaultMapOptions($opt);
    $map = '
        <script type="text/javascript">
            function getMap() {
                if (navigator.appName.indexOf ("Microsoft") !=-1) {
                    return window["jmi-flex"];
                }
                else {
                    return document["jmi-flex"];
                }
            }

            function getById(id) {
                if (navigator.appName.indexOf ("Microsoft") !=-1) {
                    return window[id];
                }
                else {
                    return document.getElementById(id);
                }
            }
            
            function ready() {
        	// do something here
            }
            
            function status(status) {
        	// do something here
            }
            
            function error(error) {
                getById("status").innerHTML = "<h3>An error occured</h3>\n" + error;	
            }

            /* Actions that are defined in swatch configuration */
            function navigate(url, target) {
                // Nothing to do here, using native flex behavior
            }
        </script>
       
        <script type="text/javascript">
             // To use express install, set to playerProductInstall.swf, otherwise the empty string.
             var flashvars = ' . json_encode($map_options) . ';
             var params = {
             	 quality: "high",
                 bgcolor: "#FFFFFF",
                 allowscriptaccess: "sameDomain",
                 allowfullscreen: "true"
             };
             var attributes = {
                 id: "jmi-flex",
                 name: "jmi-flex",
                 align: "middle"
             };
             swfobject.embedSWF(
                 "' . JMI_FILES_URL . '/jmi-flex.swf",
                 "flashContent", 
                 ' . $map_options['width'] . ',
                 ' . $map_options['height'] . ', 
                 "10.0.0",
                 "expressInstall.swf", 
                 flashvars, 
                 params, 
                 attributes);
        </script>
        <div id="status"></div>
        <div id="flashContent">
            <a href="http://www.adobe.com/go/getflashplayer">
	        <img src="http://www.adobe.com/images/shared/download_buttons/get_flash_player.gif" alt="Get Adobe Flash player" />
	    </a>
        </div>" . ';
    return $map;
}

/**
 * Shortcut to display the result of the map function above
 * 
 * @param $opt the map options
 */
function the_jmimap($opt) {
    echo jmimap($opt);
}

/**
 * Construct a link to the map section in a post page
  * 
 * @return string a link to the map section of a post
 */
function jmimap_link() {
    return '<div class="entry-map"><p>&#0187;<a href="' . get_permalink() . '#map">Afficher la carte à partir de cet article</a></p></div>';
}

/**
 * Shortcut to display the result of the jmimap_link function above
 */
function the_jmimap_link() {
    echo "<!-- link to the post jmi map -->";
    if('post' == get_post_type(get_the_ID())) {
        echo jmimap_link();
    }
}

/**
 * Shortcut to add the jmi map javascript handler functions 
 *
 * @param $opt the map options
 * @return the javascript snippet with default actions for the map
 */
function jmimap_js($opt) {
    $jsoptions = getDefaultMapOptions($opt);
    return '
        <script type="text/javascript"> 
            var parameters = ' . json_encode($jsoptions) . ';

            /* Called when an attribute is selected (node) */
            function DiscoverNode(args) {
                parameters.attributeId = args[0];
                parameters.analysisProfile = "DiscoveryProfile";
                getMap().compute(parameters);
            }
            
            /* Called when an entity is selected (link) */
            function DiscoverLink(args) {
                parameters.entityId = args[0];
                parameters.analysisProfile = "AnalysisProfile";
                getMap().compute(parameters);
            }

            /* Called when a user click on the display item on a node on the map */
            function DisplayNode(args) {
                var id   = args[0],
                    slug = args[1];
                var rel_url = (parameters.invert == true) ? "?p=" + id : "?tag=" + slug;
                redirect(rel_url);
            }
            
            /* Called when a user click on the display item on a node on the map */
            function DisplayLink(args) {
                var id   = args[0],
                    slug = args[1];
                var rel_url = (parameters.invert == true) ? "?tag=" + slug : "?p=" + id;
                redirect(rel_url);
            }

            function redirect(rel_url) {
                var redirectUrl = "' . get_bloginfo("wpurl") . '/" + rel_url;
                window.location.href = redirectUrl;
            }
        </script>
    ';
}
?>
